.. Sleep Guard documentation master file, created by
   sphinx-quickstart on Mon Jul  1 13:08:00 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include::  readme.rst

.. toctree::
   :maxdepth: 4
   :caption: Readme
   :hidden:

   readme

.. toctree::
   :maxdepth: 4
   :caption: API
   :hidden:

   api

